---
name: Bug report
about: Create a report to help us improve
title: ''
labels: bug
assignees: ''

---

**Describe the bug**
A clear and concise description of what the bug is. 

```
Please paste terminal output within these quotes 

```

**To Reproduce**
Steps to reproduce the behaviour:
1. Which runs were loaded
2. Click on '....'
3. See error

**Desktop (please complete the following information):**
 - Machine or OS: [e.g. isdaq01 or OpenSUSE]
 - Version [e.g. 4.2.5]

**Additional context**
Add any other context about the problem here.
